@@ -251,6 +251,9 @@ class Clip:
         set to ``t``.
         Also sets the duration of the mask and audio, if any, of the
         returned clip.
+        If change_end is False, the start attribute of the clip will
+        be modified in function of the duration and the preset end
+        of the clip.
         """
         self.duration = t
         if change_end:
@@ -287,7 +290,7 @@ class Clip:
             # is the whole list of t outside the clip ?
             tmin, tmax = t.min(), t.max()
             
-            if (self.end != None) and (tmin > self.end) :
+            if (self.end != None) and (tmin >= self.end) :
                 return False
             
             if tmax < self.start:
@@ -302,7 +305,7 @@ class Clip:
         else:
             
             return( (t >= self.start) and
-                    ((self.end is None) or (t <= self.end) ) )
+                    ((self.end is None) or (t < self.end) ) )
     
     @time_can_be_tuple
     @apply_to_mask
